Codec.SelectionPolicy
- class SelectionPolicy
For container formats that contain both still images and image sequences, instruct the decoder how the output should be selected.
Members:
- kPreferStillImage :
If the container format contains both still images and image sequences,
Codecshould choose one of the still images. This is the default.- kPreferAnimation :
If the container format contains both still images and image sequences,
Codecshould choose one of the image sequences for animation.
Methods
Attributes
name(-> str)
Methods
- SelectionPolicy.__init__(self: skia.Codec.SelectionPolicy, value: SupportsInt | SupportsIndex) None
Attributes
- SelectionPolicy.kPreferAnimation = <SelectionPolicy.kPreferAnimation: 1>
- SelectionPolicy.kPreferStillImage = <SelectionPolicy.kPreferStillImage: 0>
- SelectionPolicy.name -> str
- SelectionPolicy.value