FILEWStream
- class FILEWStream
Methods
Reimplemented in
FILEWStream, andNullWStream.Called to write bytes to a
WStream.Overloaded function.
Methods
- static FILEWStream.SizeOfPackedUInt(value: SupportsInt | SupportsIndex) int
- FILEWStream.__init__(self: skia.FILEWStream, path: str) None
- FILEWStream.bytesWritten(self: skia.WStream) int
- FILEWStream.flush(self: skia.WStream) None
Reimplemented in
FILEWStream, andNullWStream.
- FILEWStream.fsync(self: skia.FILEWStream) None
- FILEWStream.isValid(self: skia.FILEWStream) bool
- FILEWStream.newline(self: skia.WStream) bool
- FILEWStream.write(self: skia.WStream, buffer: typing_extensions.Buffer) bool
Called to write bytes to a
WStream.Returns true on success
- Parameters:
buffer – the address of at least size bytes to be written to the stream
size – The number of bytes in buffer to write to the stream
- Returns:
true on success
- Implemented in
DynamicMemoryWStream, FILEWStream, andNullWStream.
- FILEWStream.write16(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- FILEWStream.write32(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- FILEWStream.write8(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- FILEWStream.writeBigDecAsText(self: skia.WStream, value: SupportsInt | SupportsIndex, minDigits: SupportsInt | SupportsIndex = 0) bool
- FILEWStream.writeBool(*args, **kwargs)
Overloaded function.
writeBool(self: skia.WStream, value: bool) -> bool
writeBool(self: skia.WStream, value: bool) -> bool
- FILEWStream.writeDecAsText(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- FILEWStream.writeHexAsText(self: skia.WStream, value: SupportsInt | SupportsIndex, minDigits: SupportsInt | SupportsIndex = 0) bool
- FILEWStream.writePackedUInt(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- FILEWStream.writeScalar(self: skia.WStream, value: SupportsFloat | SupportsIndex) bool
- FILEWStream.writeScalarAsText(self: skia.WStream, value: SupportsFloat | SupportsIndex) bool
- FILEWStream.writeStream(self: skia.WStream, input: skia.Stream, length: SupportsInt | SupportsIndex) bool
- FILEWStream.writeText(self: skia.WStream, text: str) bool