GrBackendRenderTargets

GrBackendRenderTargets

Methods

MakeGL

__init__

Overloaded function.

backend

dimensions

getBackendFormat

Get the GrBackendFormat for this render target (or an invalid format if this is not valid).

getGLFramebufferInfo

If the backend API is GL, copies a snapshot of the GrGLFramebufferInfo struct into the passed in pointer and returns true.

getMockRenderTargetInfo

If the backend API is Mock, copies a snapshot of the GrMockTextureInfo struct into the passed in pointer and returns true.

getVkImageInfo

If the backend API is Vulkan, copies a snapshot of the GrVkImageInfo struct into the passed in pointer and returns true.

height

isFramebufferOnly

isProtected

isValid

sampleCnt

setVkImageLayout

Anytime the client changes the VkImageLayout of the VkImage captured by this GrBackendRenderTarget, they must call this function to notify Skia of the changed layout.

stencilBits

width

alias of GrBackendRenderTarget

Methods

static GrBackendRenderTargets.MakeGL(width: SupportsInt | SupportsIndex, height: SupportsInt | SupportsIndex, sampleCnt: SupportsInt | SupportsIndex, stencilBits: SupportsInt | SupportsIndex, glInfo: GrGLFramebufferInfo) skia.GrBackendRenderTarget
GrBackendRenderTargets.__init__(*args, **kwargs)

Overloaded function.

  1. __init__(self: skia.GrBackendRenderTarget) -> None

  2. __init__(self: skia.GrBackendRenderTarget, width: typing.SupportsInt | typing.SupportsIndex, height: typing.SupportsInt | typing.SupportsIndex, sampleCnt: typing.SupportsInt | typing.SupportsIndex, stencilBits: typing.SupportsInt | typing.SupportsIndex, glInfo: GrGLFramebufferInfo) -> None

  3. __init__(self: skia.GrBackendRenderTarget, width: typing.SupportsInt | typing.SupportsIndex, height: typing.SupportsInt | typing.SupportsIndex, vkInfo: GrVkImageInfo) -> None

  4. __init__(self: skia.GrBackendRenderTarget, width: typing.SupportsInt | typing.SupportsIndex, height: typing.SupportsInt | typing.SupportsIndex, sampleCnt: typing.SupportsInt | typing.SupportsIndex, vkInfo: GrVkImageInfo) -> None

  5. __init__(self: skia.GrBackendRenderTarget, width: typing.SupportsInt | typing.SupportsIndex, height: typing.SupportsInt | typing.SupportsIndex, sampleCnt: typing.SupportsInt | typing.SupportsIndex, stencilBits: typing.SupportsInt | typing.SupportsIndex, mockInfo: GrMockRenderTargetInfo) -> None

GrBackendRenderTargets.backend(self: skia.GrBackendRenderTarget) skia.GrBackendApi
GrBackendRenderTargets.dimensions(self: skia.GrBackendRenderTarget) skia.ISize
GrBackendRenderTargets.getBackendFormat(self: skia.GrBackendRenderTarget) skia.GrBackendFormat

Get the GrBackendFormat for this render target (or an invalid format if this is not valid).

GrBackendRenderTargets.getGLFramebufferInfo(self: skia.GrBackendRenderTarget, info: GrGLFramebufferInfo) bool

If the backend API is GL, copies a snapshot of the GrGLFramebufferInfo struct into the passed in pointer and returns true. Otherwise returns false if the backend API is not GL.

GrBackendRenderTargets.getMockRenderTargetInfo(self: skia.GrBackendRenderTarget, info: GrMockRenderTargetInfo) bool

If the backend API is Mock, copies a snapshot of the GrMockTextureInfo struct into the passed in pointer and returns true. Otherwise returns false if the backend API is not Mock.

GrBackendRenderTargets.getVkImageInfo(self: skia.GrBackendRenderTarget, info: GrVkImageInfo) bool

If the backend API is Vulkan, copies a snapshot of the GrVkImageInfo struct into the passed in pointer and returns true. This snapshot will set the fImageLayout to the current layout state. Otherwise returns false if the backend API is not Vulkan.

GrBackendRenderTargets.height(self: skia.GrBackendRenderTarget) int
GrBackendRenderTargets.isFramebufferOnly(self: skia.GrBackendRenderTarget) bool
GrBackendRenderTargets.isProtected(self: skia.GrBackendRenderTarget) bool
GrBackendRenderTargets.isValid(self: skia.GrBackendRenderTarget) bool
GrBackendRenderTargets.sampleCnt(self: skia.GrBackendRenderTarget) int
GrBackendRenderTargets.setVkImageLayout(self: skia.GrBackendRenderTarget, layout: VkImageLayout) None

Anytime the client changes the VkImageLayout of the VkImage captured by this GrBackendRenderTarget, they must call this function to notify Skia of the changed layout.

GrBackendRenderTargets.stencilBits(self: skia.GrBackendRenderTarget) int
GrBackendRenderTargets.width(self: skia.GrBackendRenderTarget) int