GrGLInterface

class GrGLInterface

Methods

MakeEGL

MakeGLX

__init__

ref

Increment the reference count.

unique

May return true if the caller is the only owner.

unref

Decrement the reference count.

validate

Methods

static GrGLInterface.MakeEGL() skia.GrGLInterface
static GrGLInterface.MakeGLX() skia.GrGLInterface
GrGLInterface.__init__(self: skia.GrGLInterface) None
GrGLInterface.ref(self: skia.RefCntBase) None

Increment the reference count.

Must be balanced by a call to unref().

GrGLInterface.unique(self: skia.RefCntBase) bool

May return true if the caller is the only owner.

Ensures that all previous owner’s actions are complete.

GrGLInterface.unref(self: skia.RefCntBase) None

Decrement the reference count.

If the reference count is 1 before the decrement, then delete the object. Note that if this is the case, then the object needs to have been allocated via new, and not on the stack.

GrGLInterface.validate(self: skia.GrGLInterface) bool