RuntimeEffect

class RuntimeEffect

Classes

ChildType

Members:

UniformType

Members:

Methods

MakeForBlender

Overloaded function.

MakeForColorFilter

Overloaded function.

MakeForShader

Overloaded function.

__init__

children

makeBlender

Overloaded function.

makeColorFilter

Overloaded function.

makeShader

Overloaded function.

ref

Increment the reference count.

uniforms

unique

May return true if the caller is the only owner.

unref

Decrement the reference count.

Attributes

kBlender

kColorFilter

kFloat

kFloat2

kFloat2x2

kFloat3

kFloat3x3

kFloat4

kFloat4x4

kInt

kInt2

kInt3

kInt4

kShader

Methods

static RuntimeEffect.MakeForBlender(*args, **kwargs)

Overloaded function.

  1. MakeForBlender(sksl: skia.String, options: SkRuntimeEffect::Options) -> skia.RuntimeEffect

  2. MakeForBlender(sksl: skia.String) -> skia.RuntimeEffect

static RuntimeEffect.MakeForColorFilter(*args, **kwargs)

Overloaded function.

  1. MakeForColorFilter(sksl: skia.String, options: SkRuntimeEffect::Options) -> skia.RuntimeEffect

  2. MakeForColorFilter(sksl: skia.String) -> skia.RuntimeEffect

static RuntimeEffect.MakeForShader(*args, **kwargs)

Overloaded function.

  1. MakeForShader(sksl: skia.String, options: SkRuntimeEffect::Options) -> skia.RuntimeEffect

  2. MakeForShader(sksl: skia.String) -> skia.RuntimeEffect

RuntimeEffect.__init__(*args, **kwargs)
RuntimeEffect.children(self: skia.RuntimeEffect) skia.SpanRuntimeEffectChild
RuntimeEffect.makeBlender(*args, **kwargs)

Overloaded function.

  1. makeBlender(self: skia.RuntimeEffect, uniforms: skia.Data) -> SkBlender

  2. makeBlender(self: skia.RuntimeEffect, uniforms: skia.Data, children: skia.SpanRuntimeEffectChildPtr = <skia.SpanRuntimeEffectChildPtr object at 0x7f20485e0cf0>) -> SkBlender

RuntimeEffect.makeColorFilter(*args, **kwargs)

Overloaded function.

  1. makeColorFilter(self: skia.RuntimeEffect, uniforms: skia.Data) -> skia.ColorFilter

  2. makeColorFilter(self: skia.RuntimeEffect, uniforms: skia.Data, children: skia.ColorFilter, childCount: typing.SupportsInt | typing.SupportsIndex) -> skia.ColorFilter

  3. makeColorFilter(self: skia.RuntimeEffect, uniforms: skia.Data, children: skia.SpanRuntimeEffectChildPtr) -> skia.ColorFilter

RuntimeEffect.makeShader(*args, **kwargs)

Overloaded function.

  1. makeShader(self: skia.RuntimeEffect, uniforms: skia.Data) -> skia.Shader

  2. makeShader(self: skia.RuntimeEffect, uniforms: skia.Data, children: skia.Shader, childCount: typing.SupportsInt | typing.SupportsIndex, localMatrix: skia.Matrix = None) -> skia.Shader

  3. makeShader(self: skia.RuntimeEffect, uniforms: skia.Data, children: skia.SpanRuntimeEffectChildPtr, localMatrix: skia.Matrix = None) -> skia.Shader

RuntimeEffect.ref(self: skia.RefCntBase) None

Increment the reference count.

Must be balanced by a call to unref().

RuntimeEffect.uniforms(self: skia.RuntimeEffect) skia.SpanRuntimeEffectUniform
RuntimeEffect.unique(self: skia.RefCntBase) bool

May return true if the caller is the only owner.

Ensures that all previous owner’s actions are complete.

RuntimeEffect.unref(self: skia.RefCntBase) None

Decrement the reference count.

If the reference count is 1 before the decrement, then delete the object. Note that if this is the case, then the object needs to have been allocated via new, and not on the stack.

Attributes

RuntimeEffect.kBlender = <ChildType.kBlender: 2>
RuntimeEffect.kColorFilter = <ChildType.kColorFilter: 1>
RuntimeEffect.kFloat = <UniformType.kFloat: 0>
RuntimeEffect.kFloat2 = <UniformType.kFloat2: 1>
RuntimeEffect.kFloat2x2 = <UniformType.kFloat2x2: 4>
RuntimeEffect.kFloat3 = <UniformType.kFloat3: 2>
RuntimeEffect.kFloat3x3 = <UniformType.kFloat3x3: 5>
RuntimeEffect.kFloat4 = <UniformType.kFloat4: 3>
RuntimeEffect.kFloat4x4 = <UniformType.kFloat4x4: 6>
RuntimeEffect.kInt = <UniformType.kInt: 7>
RuntimeEffect.kInt2 = <UniformType.kInt2: 8>
RuntimeEffect.kInt3 = <UniformType.kInt3: 9>
RuntimeEffect.kInt4 = <UniformType.kInt4: 10>
RuntimeEffect.kShader = <ChildType.kShader: 0>