VectorRuntimeEffectChild

class VectorRuntimeEffectChild

Methods

__init__

Overloaded function.

append

Add an item to the end of the list

clear

Clear the contents

extend

Overloaded function.

insert

Insert an item at a given position.

pop

Overloaded function.

Methods

VectorRuntimeEffectChild.__init__(*args, **kwargs)

Overloaded function.

  1. __init__(self: skia.VectorRuntimeEffectChild) -> None

  2. __init__(self: skia.VectorRuntimeEffectChild, arg0: collections.abc.Sequence[skia.RuntimeEffectChild]) -> None

Copy constructor

  1. __init__(self: skia.VectorRuntimeEffectChild, arg0: collections.abc.Iterable) -> None

VectorRuntimeEffectChild.append(self: collections.abc.Sequence[skia.RuntimeEffectChild], x: skia.RuntimeEffectChild) None

Add an item to the end of the list

VectorRuntimeEffectChild.clear(self: collections.abc.Sequence[skia.RuntimeEffectChild]) None

Clear the contents

VectorRuntimeEffectChild.extend(*args, **kwargs)

Overloaded function.

  1. extend(self: collections.abc.Sequence[skia.RuntimeEffectChild], L: collections.abc.Sequence[skia.RuntimeEffectChild]) -> None

Extend the list by appending all the items in the given list

  1. extend(self: collections.abc.Sequence[skia.RuntimeEffectChild], L: collections.abc.Iterable) -> None

Extend the list by appending all the items in the given list

VectorRuntimeEffectChild.insert(self: collections.abc.Sequence[skia.RuntimeEffectChild], i: SupportsInt | SupportsIndex, x: skia.RuntimeEffectChild) None

Insert an item at a given position.

VectorRuntimeEffectChild.pop(*args, **kwargs)

Overloaded function.

  1. pop(self: collections.abc.Sequence[skia.RuntimeEffectChild]) -> skia.RuntimeEffectChild

Remove and return the last item

  1. pop(self: collections.abc.Sequence[skia.RuntimeEffectChild], i: typing.SupportsInt | typing.SupportsIndex) -> skia.RuntimeEffectChild

Remove and return the item at index i