WStream
- class WStream
Subclasses
Methods
Reimplemented in
FILEWStream, andNullWStream.Called to write bytes to a
WStream.Overloaded function.
Methods
- static WStream.SizeOfPackedUInt(value: SupportsInt | SupportsIndex) int
- WStream.__init__(*args, **kwargs)
- WStream.bytesWritten(self: skia.WStream) int
- WStream.flush(self: skia.WStream) None
Reimplemented in
FILEWStream, andNullWStream.
- WStream.newline(self: skia.WStream) bool
- WStream.write(self: skia.WStream, buffer: typing_extensions.Buffer) bool
Called to write bytes to a
WStream.Returns true on success
- Parameters:
buffer – the address of at least size bytes to be written to the stream
size – The number of bytes in buffer to write to the stream
- Returns:
true on success
- Implemented in
DynamicMemoryWStream, FILEWStream, andNullWStream.
- WStream.write16(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- WStream.write32(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- WStream.write8(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- WStream.writeBigDecAsText(self: skia.WStream, value: SupportsInt | SupportsIndex, minDigits: SupportsInt | SupportsIndex = 0) bool
- WStream.writeBool(*args, **kwargs)
Overloaded function.
writeBool(self: skia.WStream, value: bool) -> bool
writeBool(self: skia.WStream, value: bool) -> bool
- WStream.writeDecAsText(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- WStream.writeHexAsText(self: skia.WStream, value: SupportsInt | SupportsIndex, minDigits: SupportsInt | SupportsIndex = 0) bool
- WStream.writePackedUInt(self: skia.WStream, value: SupportsInt | SupportsIndex) bool
- WStream.writeScalar(self: skia.WStream, value: SupportsFloat | SupportsIndex) bool
- WStream.writeScalarAsText(self: skia.WStream, value: SupportsFloat | SupportsIndex) bool
- WStream.writeStream(self: skia.WStream, input: skia.Stream, length: SupportsInt | SupportsIndex) bool
- WStream.writeText(self: skia.WStream, text: str) bool